pub enum GetFacilitiesMaintenanceResponse {
Ok(Vec<String>),
UnexpectedStatus(StatusCode, Vec<u8>),
}Expand description
Returns links to facility maintenance data files for a queried MRT/LRT station. Each link points to a JSON file describing the maintenance works currently in progress at that station.
Update freq: Ad-Hoc
Variants