pub struct GetBusStopsInput {
pub skip: Option<u32>,
}Expand description
Returns detailed information for all bus stops currently being serviced by buses, including bus stop codes and location coordinates.
Update freq: Ad-Hoc
Fields
skip: Option<u32>Number of records to skip for pagination.
Implementations